/*
 * Created: Sun Jul 20 11:42:53 1997
 *
 * Copyright (c) 1997-2005 by Frank Kardel <kardel <AT> ntp.org>
 * Copyright 2015 by the NTPsec project contributors
 * SPDX-License-Identifier: BSD-3-clause
 */
#ifndef GUARD_ASCII_H
#define GUARD_ASCII_H

/*
 * just name the common ASCII control codes
 */
#define NUL	  0
#define STX	  2
#define ETX	  3
#define SOH	  1
#define DLE	 16

#endif
/*
 * History:
 *
 * ascii.h,v
 * Revision 4.4  2005/04/16 17:32:10  kardel
 * update copyright
 *
 * Revision 4.3  2004/11/14 15:29:41  kardel
 * support PPSAPI, upgrade Copyright to Berkeley style
 *
 * Revision 4.1  1998/07/11 10:05:22  kardel
 * Release 4.0.73d reconciliation
 *
 * Revision 4.0  1998/04/10 19:50:38  kardel
 * Start 4.0 release version numbering
 *
 * Revision 4.0  1998/04/10 19:50:38  kardel
 * Start 4.0 release version numbering
 *
 */
